@@ -52,7 +52,7 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO == "cephadm" ]]; then
-        GATE_IMAGES+=",^cinder"
+        GATE_IMAGES+=",^cinder,^etcd"
     fi
 
     if [[ $SCENARIO == "cells" ]]; then
@@ -76,7 +76,7 @@ function prepare_images {
         GATE_IMAGES+=",^designate,^magnum,^trove"
     fi
     if [[ $SCENARIO == "octavia" ]]; then
-        GATE_IMAGES+=",^octavia"
+        GATE_IMAGES+=",^redis,^octavia"
     fi
     if [[ $SCENARIO == "masakari" ]]; then
         GATE_IMAGES+=",^masakari-,^hacluster-"
@@ -87,34 +87,50 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO == "ovn" ]]; then
-        GATE_IMAGES+=",^octavia,^ovn"
+        GATE_IMAGES+=",^redis,^octavia,^ovn"
     fi
 
     if [[ $SCENARIO == "mariadb" ]]; then
         GATE_IMAGES="^cron,^fluentd,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
     fi
 
+    if [[ $SCENARIO == "lets-encrypt" ]]; then
+        GATE_IMAGES+=",^letsencrypt,^haproxy"
+    fi
+
     if [[ $SCENARIO == "prometheus-opensearch" ]]; then
         GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
     fi
 
     if [[ $SCENARIO == "venus" ]]; then
-        GATE_IMAGES="^cron,^elasticsearch,^fluentd,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
+        GATE_IMAGES="^cron,^opensearch,^fluentd,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
+    fi
+
+    if [[ $SCENARIO == "skyline" ]]; then
+        GATE_IMAGES+=",^skyline"
     fi
 
     sudo tee -a /etc/kolla/kolla-build.conf <<EOF
+[DEFAULT]
+engine = ${CONTAINER_ENGINE}
+
 [profiles]
 gate = ${GATE_IMAGES}
 EOF
 
-    mkdir -p /tmp/logs/build
+    sudo mkdir -p /tmp/logs/build
+    sudo mkdir -p /opt/kolla_registry
 
     sudo $CONTAINER_ENGINE run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
 
-    python3 -m venv ~/kolla-venv
-    . ~/kolla-venv/bin/activate
 
-    pip install "${KOLLA_SRC_DIR}" "requests<2.32"
+    python3 -m venv ~/kolla-venv
+    source ~/kolla-venv/bin/activate
+    if [[ "$CONTAINER_ENGINE" == "docker" ]]; then
+        pip install "${KOLLA_SRC_DIR}" "docker<7"
+    else
+        pip install "${KOLLA_SRC_DIR}" "podman"
+    fi
 
     sudo ~/kolla-venv/bin/kolla-build
 
